@@ -1,11 +1,14 @@
 package Padre::Plugin::Perl6::Util;
+BEGIN {
+  $Padre::Plugin::Perl6::Util::VERSION = '0.66';
+}
+
+# ABSTRACT: Perl 6 plugin utilities
 
 use strict;
 use warnings;
 use Padre::Constant ();
 
-our $VERSION = '0.64';
-
 # Get perl6 full executable path
 sub perl6_exe {
 	my $exe = Padre::Constant::WIN32 ? 'perl6.exe' : 'perl6';
@@ -130,16 +133,36 @@ sub guess_newline {
 1;
 
 __END__
+=pod
 
-=head1 AUTHOR
+=head1 NAME
 
-Ahmad M. Zawawi C<< <ahmad.zawawi at gmail.com> >>
+Padre::Plugin::Perl6::Util - Perl 6 plugin utilities
+
+=head1 VERSION
+
+version 0.66
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Ahmad M. Zawawi <ahmad.zawawi@gmail.com>
+
+=item *
 
 Gabor Szabo L<http://szabgab.com/>
 
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008-2009 Padre Developers as in Perl6.pm
+This software is copyright (c) 2010 by Ahmad M. Zawawi.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
 
-This program is free software; you can redistribute it and/or
-modify it under the same terms as Perl 5 itself.
